==> modx-cms-1.0.3.zip: modx-1.0.3/assets/modules/docmanager/lang/russian.inc.php <==
<?php
/**
 * Document Manager Module - language strings for use in the module
 *
 * Filename:       assets/modules/docmanager/lang/russian.inc.php
 * Language:       Russian
 * Encoding:       Windows-1251
 * Translated by:  Jaroslav Sidorkin
 * Date:           30 July 2009
 * Version:        1.0
 */
 
//-- RUSSIAN LANGUAGE FILE
 
//-- titles
$_lang['DM_module_title'] = ' ';
$_lang['DM_action_title'] = ' ';
$_lang['DM_range_title'] = '  ID ';
$_lang['DM_tree_title'] = '   ';
$_lang['DM_update_title'] = ' ';
$_lang['DM_sort_title'] = '  ';

//-- tabs
$_lang['DM_doc_permissions'] = '   ';
$_lang['DM_template_variables'] = '  (TV)';
$_lang['DM_sort_menu'] = '  ';
$_lang['DM_change_template'] = ' ';
$_lang['DM_publish'] = ' /  ';
$_lang['DM_other'] = ' ';
 
//-- buttons
$_lang['DM_close'] = '  ';
$_lang['DM_cancel'] = '';
$_lang['DM_go'] = '';
$_lang['DM_save'] = '';
$_lang['DM_sort_another'] = ' ';

//-- templates tab
$_lang['DM_tpl_desc'] = '   ,    ,   ID ,      .    ID    .';
$_lang['DM_tpl_no_templates'] = '  ';
$_lang['DM_tpl_column_id'] = 'ID';
$_lang['DM_tpl_column_name'] = '';
$_lang['DM_tpl_column_description'] = '';
$_lang['DM_tpl_blank_template'] = ' ';

$_lang['DM_tpl_results_message'] = '     - ,   "".    .';

//-- template variables tab
$_lang['DM_tv_desc'] = '   ,  (TV)     /  -         (TV) .      (TV)        (TV),     .   ID ,         (TV).    ID     .';
$_lang['DM_tv_template_mismatch'] = '     .';
$_lang['DM_tv_doc_not_found'] = '      .';
$_lang['DM_tv_no_tv'] = '  (TV),   .';
$_lang['DM_tv_no_docs'] = '    .';
$_lang['DM_tv_no_template_selected'] = '  .';
$_lang['DM_tv_loading'] = '  (TV)...';
$_lang['DM_tv_ignore_tv'] = '   (TV) (  ):';
$_lang['DM_tv_ajax_insertbutton'] = '';

//-- document permissions tab
$_lang['DM_doc_desc'] = '        ( / ),   ID ,    .    ID     .';
$_lang['DM_doc_no_docs'] = '  . (      " &gt;  ( / -) &gt;  ".)';
$_lang['DM_doc_column_id'] = 'ID';
$_lang['DM_doc_column_name'] = '  ';
$_lang['DM_doc_radio_add'] = '   ';
$_lang['DM_doc_radio_remove'] = '   ';

$_lang['DM_doc_skip_message1'] = '  ID';
$_lang['DM_doc_skip_message2'] = '      ()';

//-- sort menu tab
$_lang['DM_sort_pick_item'] = '       ,        .'; 
$_lang['DM_sort_updating'] = '  ...';
$_lang['DM_sort_updated'] = '  ';
$_lang['DM_sort_nochildren'] = '      .';
$_lang['DM_sort_noid'] = '      . ,  ""   .';

//-- other tab
$_lang['DM_other_header'] = '  ';
$_lang['DM_misc_label'] = ' :';
$_lang['DM_misc_desc'] = '          .        .';

$_lang['DM_other_dropdown_publish'] = ' /  ';
$_lang['DM_other_dropdown_show'] = ' /    ';
$_lang['DM_other_dropdown_search'] = ' /    ';
$_lang['DM_other_dropdown_cache'] = ' /  ';
$_lang['DM_other_dropdown_richtext'] = ' /   HTML-';
$_lang['DM_other_dropdown_delete'] = ' /  ';

//-- radio button text
$_lang['DM_other_publish_radio1'] = ''; 
$_lang['DM_other_publish_radio2'] = ' ';
$_lang['DM_other_show_radio1'] = '   '; 
$_lang['DM_other_show_radio2'] = '  ';
$_lang['DM_other_search_radio1'] = ' '; 
$_lang['DM_other_search_radio2'] = ' ';
$_lang['DM_other_cache_radio1'] = ''; 
$_lang['DM_other_cache_radio2'] = ' ';
$_lang['DM_other_richtext_radio1'] = ' HTML-'; 
$_lang['DM_other_richtext_radio2'] = '  HTML-';
$_lang['DM_other_delete_radio1'] = ''; 
$_lang['DM_other_delete_radio2'] = ' ';

//-- adjust dates 
$_lang['DM_adjust_dates_header'] = '  ';
$_lang['DM_adjust_dates_desc'] = '      .  ""   .';
$_lang['DM_view_calendar'] = '';
$_lang['DM_clear_date'] = ' ';

//-- adjust authors
$_lang['DM_adjust_authors_header'] = '  / ';
$_lang['DM_adjust_authors_desc'] = '   /     .';
$_lang['DM_adjust_authors_createdby'] = ' :';
$_lang['DM_adjust_authors_editedby'] = ' :';
$_lang['DM_adjust_authors_noselection'] = ' ';

 //-- labels
$_lang['DM_date_pubdate'] = ' :';
$_lang['DM_date_unpubdate'] = '  :';
$_lang['DM_date_createdon'] = '  :';
$_lang['DM_date_editedon'] = '   :';
//$_lang['DM_date_deletedon'] = '  ';

$_lang['DM_date_notset'] = ' ( )';
//deprecated
$_lang['DM_date_dateselect_label'] = ' : ';

//-- document select section
$_lang['DM_select_submit'] = '';
$_lang['DM_select_range'] = '    ID ';
$_lang['DM_select_range_text'] = '<p><b>       ( "n"   ID ):</b><br />
							  <ul><li><b>n*</b> -     ID=n    ;</li>
							  <li><b>n**</b> -     ID=n     ;</li>
							  <li><b>n-n2</b> -     , ID     ;</li>
							  <li><b>n</b> -       ID=n;</li>
							  <li><b>n*,n**,n-n2,n</b> -     ,   .</li></ul></p>
							  <p><b>:</b> 1*,4**,2-20,25 -       ID=1     ,   ID=4     ,   ID    2  20,    ID=25.</p>';
$_lang['DM_select_tree'] = '     ';

//-- process tree/range messages
$_lang['DM_process_noselection'] = '  . ';
$_lang['DM_process_novalues'] = '   .';
$_lang['DM_process_limits_error'] = '     :';
$_lang['DM_process_invalid_error'] = ' :';
$_lang['DM_process_update_success'] = '  .';
$_lang['DM_process_update_error'] = '   :';
$_lang['DM_process_back'] = '';

//-- manager access logging
$_lang['DM_log_template'] = ' :  .';
$_lang['DM_log_templatevariables'] = ' :  (TV) .';
$_lang['DM_log_docpermissions'] = ' :    .';
$_lang['DM_log_sortmenu'] = ' :     .';
$_lang['DM_log_publish'] = ' :   " /  " .';
$_lang['DM_log_hidemenu'] = ' :   " /    " .';
$_lang['DM_log_search'] = ' :   " /    " .';
$_lang['DM_log_cache'] = ' :   " /  " .';
$_lang['DM_log_richtext'] = ' :   " /   HTML-" .';
$_lang['DM_log_delete'] = ' :  /    .';
$_lang['DM_log_dates'] = ' :   .';
$_lang['DM_log_authors'] = ' :   .';

?>

==> modx-cms-1.0.5.zip: modx-1.0.5/assets/modules/docmanager/lang/russian.inc.php <==
<?php
/**
 * Document Manager Module - language strings for use in the module
 *
 * Filename:       assets/modules/docmanager/lang/russian.inc.php
 * Language:       Russian
 * Encoding:       Windows-1251
 * Translated by:  Jaroslav Sidorkin
 * Date:           28 April 2010
 * Version:        1.0.1
 */
 
//-- RUSSIAN LANGUAGE FILE
 
//-- titles
$_lang['DM_module_title'] = ' ';
$_lang['DM_action_title'] = ' ';
$_lang['DM_range_title'] = '  ID ';
$_lang['DM_tree_title'] = '   ';
$_lang['DM_update_title'] = ' ';
$_lang['DM_sort_title'] = '  ';

//-- tabs
$_lang['DM_doc_permissions'] = '   ';
$_lang['DM_template_variables'] = '  (TV)';
$_lang['DM_sort_menu'] = '  ';
$_lang['DM_change_template'] = ' ';
$_lang['DM_publish'] = ' /  ';
$_lang['DM_other'] = ' ';
 
//-- buttons
$_lang['DM_close'] = '  ';
$_lang['DM_cancel'] = '';
$_lang['DM_go'] = '';
$_lang['DM_save'] = '';
$_lang['DM_sort_another'] = ' ';

//-- templates tab
$_lang['DM_tpl_desc'] = '   ,    ,   ID ,      .    ID    .';
$_lang['DM_tpl_no_templates'] = '  ';
$_lang['DM_tpl_column_id'] = 'ID';
$_lang['DM_tpl_column_name'] = '';
$_lang['DM_tpl_column_description'] = '';
$_lang['DM_tpl_blank_template'] = ' ';

$_lang['DM_tpl_results_message'] = '     - ,   "".    .';

//-- template variables tab
$_lang['DM_tv_desc'] = '   ,  (TV)     /  -         (TV) .      (TV)        (TV),     .   ID ,         (TV).    ID     .';
$_lang['DM_tv_template_mismatch'] = '     .';
$_lang['DM_tv_doc_not_found'] = '      .';
$_lang['DM_tv_no_tv'] = '  (TV),   .';
$_lang['DM_tv_no_docs'] = '    .';
$_lang['DM_tv_no_template_selected'] = '  .';
$_lang['DM_tv_loading'] = '  (TV)...';
$_lang['DM_tv_ignore_tv'] = '   (TV) (  ):';
$_lang['DM_tv_ajax_insertbutton'] = '';

//-- document permissions tab
$_lang['DM_doc_desc'] = '        ( / ),   ID ,    .    ID     .';
$_lang['DM_doc_no_docs'] = '  . (      " &gt;  ( / -) &gt;  ".)';
$_lang['DM_doc_column_id'] = 'ID';
$_lang['DM_doc_column_name'] = '  ';
$_lang['DM_doc_radio_add'] = '   ';
$_lang['DM_doc_radio_remove'] = '   ';

$_lang['DM_doc_skip_message1'] = '  ID';
$_lang['DM_doc_skip_message2'] = '      ()';

//-- sort menu tab
$_lang['DM_sort_pick_item'] = '       ,        .'; 
$_lang['DM_sort_updating'] = '  ...';
$_lang['DM_sort_updated'] = '  ';
$_lang['DM_sort_nochildren'] = '      .';
$_lang['DM_sort_noid'] = '      . ,  ""   .';

//-- other tab
$_lang['DM_other_header'] = '  ';
$_lang['DM_misc_label'] = ' :';
$_lang['DM_misc_desc'] = '          .        .';

$_lang['DM_other_dropdown_publish'] = ' /  ';
$_lang['DM_other_dropdown_show'] = ' /    ';
$_lang['DM_other_dropdown_search'] = ' /    ';
$_lang['DM_other_dropdown_cache'] = ' /  ';
$_lang['DM_other_dropdown_richtext'] = ' /   HTML-';
$_lang['DM_other_dropdown_delete'] = ' /  ';

//-- radio button text
$_lang['DM_other_publish_radio1'] = ''; 
$_lang['DM_other_publish_radio2'] = ' ';
$_lang['DM_other_show_radio1'] = '   '; 
$_lang['DM_other_show_radio2'] = '  ';
$_lang['DM_other_search_radio1'] = ' '; 
$_lang['DM_other_search_radio2'] = ' ';
$_lang['DM_other_cache_radio1'] = ''; 
$_lang['DM_other_cache_radio2'] = ' ';
$_lang['DM_other_richtext_radio1'] = ' HTML-'; 
$_lang['DM_other_richtext_radio2'] = '  HTML-';
$_lang['DM_other_delete_radio1'] = ''; 
$_lang['DM_other_delete_radio2'] = ' ';

//-- adjust dates 
$_lang['DM_adjust_dates_header'] = '  ';
$_lang['DM_adjust_dates_desc'] = '      .  ""   .';
$_lang['DM_view_calendar'] = '';
$_lang['DM_clear_date'] = ' ';

//-- adjust authors
$_lang['DM_adjust_authors_header'] = '  / ';
$_lang['DM_adjust_authors_desc'] = '   /     .';
$_lang['DM_adjust_authors_createdby'] = ' :';
$_lang['DM_adjust_authors_editedby'] = ' :';
$_lang['DM_adjust_authors_noselection'] = ' ';

 //-- labels
$_lang['DM_date_pubdate'] = ' :';
$_lang['DM_date_unpubdate'] = '  :';
$_lang['DM_date_createdon'] = '  :';
$_lang['DM_date_editedon'] = '   :';
//$_lang['DM_date_deletedon'] = '  ';

$_lang['DM_date_notset'] = ' ( )';
//deprecated
$_lang['DM_date_dateselect_label'] = ' : ';

//-- document select section
$_lang['DM_select_submit'] = '';
$_lang['DM_select_range'] = '    ID ';
$_lang['DM_select_range_text'] = '<p><b>       ( &quot;n&quot;   ID ):</b></p>
<ul>
	<li><b>n*</b> -     ID=n    ;</li>
	<li><b>n**</b> -     ID=n     ;</li>
	<li><b>n-n2</b> -     , ID     ;</li>
	<li><b>n</b> -       ID=n;</li>
	<li><b>n*,n**,n-n2,n</b> -     ,   .</li>
</ul><br /><p><b>:</b> 1*,4**,2-20,25 -       ID=1     ,   ID=4     ,   ID    2  20,    ID=25.</p>';
$_lang['DM_select_tree'] = '     ';

//-- process tree/range messages
$_lang['DM_process_noselection'] = '  . ';
$_lang['DM_process_novalues'] = '   .';
$_lang['DM_process_limits_error'] = '     :';
$_lang['DM_process_invalid_error'] = ' :';
$_lang['DM_process_update_success'] = '  .';
$_lang['DM_process_update_error'] = '   :';
$_lang['DM_process_back'] = '';

//-- manager access logging
$_lang['DM_log_template'] = ' :  .';
$_lang['DM_log_templatevariables'] = ' :  (TV) .';
$_lang['DM_log_docpermissions'] = ' :    .';
$_lang['DM_log_sortmenu'] = ' :     .';
$_lang['DM_log_publish'] = ' :   " /  " .';
$_lang['DM_log_hidemenu'] = ' :   " /    " .';
$_lang['DM_log_search'] = ' :   " /    " .';
$_lang['DM_log_cache'] = ' :   " /  " .';
$_lang['DM_log_richtext'] = ' :   " /   HTML-" .';
$_lang['DM_log_delete'] = ' :  /    .';
$_lang['DM_log_dates'] = ' :   .';
$_lang['DM_log_authors'] = ' :   .';

?>
